K-Pop detects population structure from SNP data. It has an interface to run
the popular Structure and ADMIX programs from Python and also implements a novel
k-means based approach for clustering of genetic data.

These are Python binding to the Structure (http://pritch.bsd.uchicago.edu/structure.html)
program.